@@ -5,10 +5,8 @@ from gemini import GeminiQuery
 from gemini import gemini_constants as const
 from gemini import gemini_subjects as subjects
 
-database = sys.argv[1]
 
-
-gq = GeminiQuery(database)
+gq = GeminiQuery.GeminiQueryPostgres(database)
 query = "SELECT variant_id, chrom, start, end, \
                     ref, alt, gene, impact, gts, gt_types, \
                     gt_ref_depths, gt_alt_depths \
@@ -16,15 +14,8 @@ query = "SELECT variant_id, chrom, start, end, \
 
 families = subjects.get_families(database)
 
-gq.run(query, gt_filter="gt_types.(hair_color='purple').(==HET) and gts.M128215 == 'T/T'")
-#smp2idx = gq.sample_to_idx
-#idx = smp2idx['NA12878']
-
-for family in families:
-    print family.father_name, family.mother_name, [str(child.name) for child in family.children]
+gq.run(query, gt_filter="(gt_types).(*).(==HOM_ALT).(any)")
 
 for row in gq:
     print row
-    #if row['gt_types'][idx] == const.HET:
-    #    print row, row['gts'][idx]
 
