@@ -3,3 +3,7 @@
 wget https://s3.amazonaws.com/biodata/variants/cosmic-v67_20131024-hg19.vcf.gz
 mv cosmic-v67_20131024-hg19.vcf.gz hg19.cosmic.v67.20131024.gz
 tabix -p hg19.cosmic.v67.20131024.gz
+
+# Version 68
+wget https://s3.amazonaws.com/biodata/variants/cosmic-v68-GRCh37.vcf.gz
+wget https://s3.amazonaws.com/biodata/variants/cosmic-v68-GRCh37.vcf.gz.tbi
