@@ -12,6 +12,7 @@
 #	> dbsnp.138.vcf.gz.tbi
 
 
-curl ftp://ftp.ncbi.nih.gov/snp/organisms/human_9606_b141_GRCh37p13/VCF/00-All.vcf.gz > dbsnp.b141.vcf.gz
-gunzip dbsnp.b141.vcf.gz | bgzip -c > dbsnp.hg19.b141.vcf.gz
-tabix -p vcf dbsnp.hg19.b141.vcf.gz
\ No newline at end of file
+# curl ftp://ftp.ncbi.nih.gov/snp/organisms/human_9606_b141_GRCh37p13/VCF/00-All.vcf.gz > dbsnp.b141.vcf.gz
+curl ftp://ftp.ncbi.nih.gov/snp/organisms/human_9606_b141_GRCh37p13/VCF/All.vcf.gz > dbsnp.b141.20140813.vcf.gz
+gunzip dbsnp.b141.20140813.vcf.gz | bgzip -c > dbsnp.b141.20140813.hg19.vcf.gz
+tabix -p vcf dbsnp.b141.20140813.hg19.vcf.gz
\ No newline at end of file
