@@ -19,7 +19,7 @@ def get_anno_files( args ):
     annos = {
      'pfam_domain': os.path.join(anno_dirname, 'hg19.pfam.ucscgenes.bed.gz'),
      'cytoband': os.path.join(anno_dirname, 'hg19.cytoband.bed.gz'),
-     'dbsnp': os.path.join(anno_dirname, 'dbsnp.hg19.b141.vcf.gz'),
+     'dbsnp': os.path.join(anno_dirname, 'dbsnp.b141.20140813.hg19.vcf.gz'),
      'clinvar': os.path.join(anno_dirname, 'clinvar_20140807.vcf.gz'),
      'gwas': os.path.join(anno_dirname, 'hg19.gwas.bed.gz'),
      'rmsk': os.path.join(anno_dirname, 'hg19.rmsk.bed.gz'),
@@ -30,7 +30,7 @@ def get_anno_files( args ):
      'esp': os.path.join(anno_dirname,
                          'ESP6500SI.all.snps_indels.vcf.gz'),
      '1000g': os.path.join(anno_dirname,
-                           'ALL.wgs.integrated_phase1_v3.20101123.snps_indels_sv.sites.2012Oct12.vcf.gz'),
+                           'ALL.autosomes.phase3_shapeit2_mvncall_integrated_v5.20130502.sites.vcf.gz'),
      'recomb': os.path.join(anno_dirname,
                             'genetic_map_HapMapII_GRCh37.gz'),
      'gms': os.path.join(anno_dirname,
@@ -46,7 +46,8 @@ def get_anno_files( args ):
      'gerp_elements': os.path.join(anno_dirname, 'hg19.gerp.elements.bed.gz'),
      'vista_enhancers': os.path.join(anno_dirname, 'hg19.vista.enhancers.20131108.bed.gz'),
      'fitcons': os.path.join(anno_dirname, "hg19_fitcons_fc-i6-0_V1-01.bw"),
-     'cosmic': os.path.join(anno_dirname, 'cosmic-v68-GRCh37.vcf.gz')
+     'cosmic': os.path.join(anno_dirname, 'cosmic-v68-GRCh37.vcf.gz'),
+     'exac': os.path.join(anno_dirname, 'ExAC.r0.2.sites.vep.vcf.gz')
     }
     # optional annotations
     if os.path.exists(os.path.join(anno_dirname, 'hg19.gerp.bw')):
@@ -68,6 +69,7 @@ class ClinVarInfo(object):
         self.clinvar_in_omim = None
         self.clinvar_in_locus_spec_db = None
         self.clinvar_on_diag_assay = None
+        self.clinvar_causal_allele = None
 
         self.origin_code_map = {'0': 'unknown',
                                 '1': 'germline',
@@ -103,7 +105,8 @@ class ClinVarInfo(object):
                           self.clinvar_disease_acc,
                           str(self.clinvar_in_omim),
                           str(self.clinvar_in_locus_spec_db),
-                          str(self.clinvar_on_diag_assay)])
+                          str(self.clinvar_on_diag_assay),
+                          str(self.clinvar_causal_allele)])
 
     def lookup_clinvar_origin(self, origin_code):
         try:
@@ -150,10 +153,25 @@ ThousandGInfo = collections.namedtuple("ThousandGInfo",
                                        "found \
                                         aaf_ALL \
                                         aaf_AMR \
-                                        aaf_ASN \
+                                        aaf_EAS \
+                                        aaf_SAS \
                                         aaf_AFR \
                                         aaf_EUR")
 
+GmsTechs = collections.namedtuple("GmsTechs", "illumina solid iontorrent")
+
+ExacInfo = collections.namedtuple("ExacInfo",
+                                  "found \
+                                   aaf_ALL \
+                                   adj_aaf_ALL \
+                                   aaf_AFR \
+                                   aaf_AMR \
+                                   aaf_EAS \
+                                   aaf_FIN \
+                                   aaf_NFE \
+                                   aaf_OTH \
+                                   aaf_SAS")
+
 def load_annos( args ):
     """
     Populate a dictionary of Tabixfile handles for
@@ -471,6 +489,7 @@ def get_clinvar_info(var):
     # clinvar_in_omim          = OM
     # clinvar_in_locus_spec_db = LSD
     # clinvar_on_diag_assay    = CDA
+    # clinvar_causal_allele    = CLNALLE=1
     """
 
     clinvar = ClinVarInfo()
@@ -507,6 +526,27 @@ def get_clinvar_info(var):
         clinvar.clinvar_in_locus_spec_db = 1 if 'LSD' in info_map else 0
         clinvar.clinvar_on_diag_assay = 1 if 'CDA' in info_map else 0
 
+        causal_allele_numbers = info_map['CLNALLE'].split(',') # CLNALLE=0,1 or CLNALLE=0 or CLNALLE=1
+        if len(causal_allele_numbers) == 1:
+            causal_allele_number = int(causal_allele_numbers[0])          
+            if causal_allele_number == -1 or causal_allele_number is None:
+              clinvar.clinvar_causal_allele = None
+            elif causal_allele_number == 0:
+              clinvar.clinvar_causal_allele = hit.ref
+            elif causal_allele_number > 0:
+              clinvar.clinvar_causal_allele = hit.alt[causal_allele_number - 1]
+        else:
+            clinvar_causal_allele = ""
+            for idx, allele_num in enumerate(causal_allele_numbers):
+                causal_allele_number = int(allele_num)
+                if idx > 0:
+                    clinvar_causal_allele += ","
+                if causal_allele_number == 0:
+                    clinvar_causal_allele += hit.ref
+                elif causal_allele_number > 0:
+                    clinvar_causal_allele += hit.alt.split(',')[causal_allele_number - 1]
+
+            clinvar.clinvar_causal_allele = clinvar_causal_allele
     return clinvar
 
 
@@ -517,13 +557,6 @@ def get_dbsnp_info(var):
     rs_ids = []
     for hit in annotations_in_region(var, "dbsnp", "vcf", "grch37"):
         rs_ids.append(hit.id)
-        # load each VCF INFO key/value pair into a DICT
-        info_map = {}
-        for info in hit.info.split(";"):
-            if info.find("=") > 0:
-                (key, value) = info.split("=")
-                info_map[key] = value
-
     return ",".join(rs_ids) if len(rs_ids) > 0 else None
 
 
@@ -605,8 +638,101 @@ def get_1000G_info(var):
             found = True
 
     return ThousandGInfo(found, info_map.get('AF'), info_map.get('AMR_AF'),
-                         info_map.get('ASN_AF'), info_map.get('AFR_AF'),
-                         info_map.get('EUR_AF'))
+                         info_map.get('EAS_AF'), info_map.get('SAS_AF'), 
+                         info_map.get('AFR_AF'), info_map.get('EUR_AF'))
+
+def get_exac_info(var):
+    """
+    Returns the allele frequencies from the Exac data (Broad)
+    """
+
+    info_map = {}
+    found = False
+    adj_aaf_ALL = aaf_AFR = aaf_AMR = aaf_EAS = None
+    aaf_FIN = aaf_NFE = aaf_OTH = aaf_SAS = None
+
+    for hit in annotations_in_region(var,"exac", "vcf", "grch37"):
+        if var.start == hit.pos and \
+                var.REF == hit.ref and \
+                   var.ALT[0] == hit.alt:
+
+            found = True
+            for info in hit.info.split(";"):
+                if info.find("=") > 0:
+                    (key, value) = info.split("=", 1)
+                    info_map[key] = value
+
+            # Population independent raw (not-adjusted) allele frequencies given by AF
+            # Computing population independent allele frequencies (adjusted)
+            if info_map.get('AC_Adj') is not None and \
+                        info_map.get('AN_Adj') is not None:
+                # In case of multiple alt alleles, consider the first
+                ac_all = info_map['AC_Adj'].split(",")
+                try:
+                    adj_aaf_ALL = float(ac_all[0]) / float(info_map.get('AN_Adj'))
+                except ZeroDivisionError:
+                    # Cases where adj_AC and adj_AN were zero
+                    adj_aaf_ALL = 0
+
+            # Computing population specific allele frequencies
+            if info_map.get('AC_AFR') is not None and \
+                        info_map.get('AN_AFR') is not None:
+                ac_afr = info_map['AC_AFR'].split(",")
+                try:
+                    aaf_AFR = float(ac_afr[0]) / float(info_map.get('AN_AFR'))
+                except ZeroDivisionError:
+                    aaf_AFR = 0
+
+            if info_map.get('AC_AMR') is not None and \
+                        info_map.get('AN_AMR') is not None:
+                ac_amr = info_map['AC_AMR'].split(",")
+                try:
+                    aaf_AMR = float(ac_amr[0]) / float(info_map.get('AN_AMR'))
+                except ZeroDivisionError:
+                    aaf_AMR = 0
+
+            if info_map.get('AC_EAS') is not None and \
+                        info_map.get('AN_EAS') is not None:
+                ac_eas = info_map['AC_EAS'].split(",")
+                try:
+                    aaf_EAS = float(ac_eas[0]) / float(info_map.get('AN_EAS'))
+                except ZeroDivisionError:
+                    aaf_EAS = 0
+
+            if info_map.get('AC_FIN') is not None and \
+                        info_map.get('AN_FIN') is not None:
+                ac_fin = info_map['AC_FIN'].split(",")
+                try:
+                    aaf_FIN = float(ac_fin[0]) / float(info_map.get('AN_FIN'))
+                except ZeroDivisionError:
+                    aaf_FIN = 0
+
+            if info_map.get('AC_NFE') is not None and \
+                        info_map.get('AN_NFE') is not None:
+                ac_nfe = info_map['AC_NFE'].split(",")
+                try:
+                    aaf_NFE = float(ac_nfe[0]) / float(info_map.get('AN_NFE'))
+                except ZeroDivisionError:
+                    aaf_NFE = 0
+
+            if info_map.get('AC_OTH') is not None and \
+                        info_map.get('AN_OTH') is not None:
+                ac_oth = info_map['AC_OTH'].split(",")
+                try:
+                    aaf_OTH = float(ac_oth[0]) / float(info_map.get('AN_OTH'))
+                except ZeroDivisionError:
+                    aaf_OTH = 0
+
+            if info_map.get('AC_SAS') is not None and \
+                        info_map.get('AN_SAS') is not None:
+                ac_sas = info_map['AC_SAS'].split(",")
+                try:
+                    aaf_SAS = float(ac_sas[0]) / float(info_map.get('AN_SAS'))
+                except ZeroDivisionError:
+                    aaf_SAS = 0
+
+    return ExacInfo(found, info_map.get('AF'), adj_aaf_ALL, aaf_AFR, aaf_AMR, aaf_EAS,
+                     aaf_FIN, aaf_NFE, aaf_OTH, aaf_SAS)
 
 
 def get_rmsk_info(var):
@@ -685,7 +811,6 @@ def get_gms(var):
     """Return Genome Mappability Scores for multiple technologies.
     """
     techs = ["illumina", "solid", "iontorrent"]
-    GmsTechs = collections.namedtuple("GmsTechs", techs)
     hit = _get_first_vcf_hit(
         annotations_in_region(var, "gms", "vcf", "grch37"))
     attr_map = _get_vcf_info_attrs(hit) if hit is not None else {}
