@@ -38,6 +38,7 @@ def index_variation(cursor):
     cursor.execute('''create index var_cadd_raw_idx on variants(cadd_raw)''')
     cursor.execute('''create index var_cadd_scaled_idx on variants(cadd_scaled)''')
     cursor.execute('''create index var_fitcons_idx on variants(fitcons)''')
+    cursor.execute('''create index var_sv_event_idx on variants(sv_event_id)''')
 
 
 def index_variation_impacts(cursor):
@@ -110,9 +111,21 @@ def create_tables(cursor):
                     gt_ref_depths blob,                         \
                     gt_alt_depths blob,                         \
                     gt_quals blob,                              \
+                    gt_copy_numbers blob,                       \
                     call_rate float,                            \
                     in_dbsnp bool,                              \
                     rs_ids text default NULL,                   \
+                    sv_cipos_start_left integer,                \
+                    sv_cipos_end_left integer,                  \
+                    sv_cipos_start_right integer,               \
+                    sv_cipos_end_right integer,                 \
+                    sv_length integer,                          \
+                    sv_is_precise bool,                         \
+                    sv_tool text,                               \
+                    sv_evidence_type text,                      \
+                    sv_event_id text,                           \
+                    sv_mate_id text,                            \
+                    sv_strand text,                             \
                     in_omim bool,                               \
                     clinvar_sig text default NULL,              \
                     clinvar_disease_name text default NULL,     \
@@ -124,6 +137,7 @@ def create_tables(cursor):
                     clinvar_disease_acc text default NULL,      \
                     clinvar_in_locus_spec_db bool,              \
                     clinvar_on_diag_assay bool,                 \
+                    clinvar_causal_allele text,                 \
                     pfam_domain text,                           \
                     cyto_band text default NULL,                \
                     rmsk text default NULL,                     \
@@ -174,7 +188,8 @@ def create_tables(cursor):
                     allele_bal float default NULL,              \
                     in_hm2 bool,                                \
                     in_hm3 bool,                                \
-                    is_somatic,                                 \
+                    is_somatic bool,                            \
+                    somatic_score float,                        \
                     in_esp bool,                                \
                     aaf_esp_ea decimal(2,7),                    \
                     aaf_esp_aa decimal(2,7),                    \
@@ -182,7 +197,8 @@ def create_tables(cursor):
                     exome_chip bool,                            \
                     in_1kg bool,                                \
                     aaf_1kg_amr decimal(2,7),                   \
-                    aaf_1kg_asn decimal(2,7),                   \
+                    aaf_1kg_eas decimal(2,7),                   \
+                    aaf_1kg_sas decimal(2,7),                   \
                     aaf_1kg_afr decimal(2,7),                   \
                     aaf_1kg_eur decimal(2,7),                   \
                     aaf_1kg_all decimal(2,7),                   \
@@ -206,6 +222,16 @@ def create_tables(cursor):
                     cadd_raw float,                             \
                     cadd_scaled float,                          \
                     fitcons float,                              \
+                    in_exac bool,                               \
+                    aaf_exac_all decimal(2,7),                  \
+                    aaf_adj_exac_all decimal(2,7),              \
+                    aaf_adj_exac_afr decimal(2,7),                  \
+                    aaf_adj_exac_amr decimal(2,7),                  \
+                    aaf_adj_exac_eas decimal(2,7),                  \
+                    aaf_adj_exac_fin decimal(2,7),                  \
+                    aaf_adj_exac_nfe decimal(2,7),                  \
+                    aaf_adj_exac_oth decimal(2,7),                  \
+                    aaf_adj_exac_sas decimal(2,7),                  \
                     PRIMARY KEY(variant_id ASC))''')
 
     cursor.execute('''create table if not exists variant_impacts  (   \
@@ -314,7 +340,9 @@ def _insert_variation_one_per_transaction(cursor, buffer):
                                                              ?,?,?,?,?,?,?,?,?,?, \
                                                              ?,?,?,?,?,?,?,?,?,?, \
                                                              ?,?,?,?,?,?,?,?,?,?, \
-                                                             ?,?,?,?,?)', variant)
+                                                             ?,?,?,?,?,?,?,?,?,?, \
+                                                             ?,?,?,?,?,?,?,?,?,?, \
+                                                             ?,?,?,?,?,?,?,?,?,?)', variant)
             cursor.execute("END TRANSACTION")
         # skip repeated keys until we get to the failed variant
         except sqlite3.IntegrityError, e:
@@ -342,7 +370,9 @@ def insert_variation(cursor, buffer):
                                                          ?,?,?,?,?,?,?,?,?,?, \
                                                          ?,?,?,?,?,?,?,?,?,?, \
                                                          ?,?,?,?,?,?,?,?,?,?, \
-                                                         ?,?,?,?,?)', buffer)
+                                                         ?,?,?,?,?,?,?,?,?,?, \
+                                                         ?,?,?,?,?,?,?,?,?,?, \
+                                                         ?,?,?,?,?,?,?,?,?,?)', buffer)
 
         cursor.execute("END TRANSACTION")
     except sqlite3.ProgrammingError:
