@@ -15,7 +15,10 @@ def get_actionable_mutations(parser, args):
                     gene_summary.in_cosmic_census \
              FROM variants, gene_summary \
              WHERE variants.is_somatic = 1 \
-             AND variants.is_exonic = 1 \
+             AND (variants.type = 'snp' \
+                 OR variants.type = 'indel') \
+             AND (variants.impact_severity = 'HIGH' \
+                 OR variants.impact_severity = 'MED') \
              AND variants.chrom = gene_summary.chrom \
              AND variants.gene = gene_summary.gene \
              AND gene_summary.in_cosmic_census = 1"
