@@ -21,6 +21,7 @@ import annotations
 import func_impact
 import severe_impact
 import popgen
+import structural_variants as svs
 from gemini_constants import *
 from compression import pack_blob
 from gemini.config import read_gemini_config
@@ -278,40 +279,71 @@ class GeminiLoader(object):
 
         ############################################################
         # collect annotations from gemini's custom annotation files
+        # but only if the size of the variant is <= 50kb
         ############################################################
-        pfam_domain = annotations.get_pfamA_domains(var)
-        cyto_band = annotations.get_cyto_info(var)
-        rs_ids = annotations.get_dbsnp_info(var)
-        clinvar_info = annotations.get_clinvar_info(var)
-        in_dbsnp = 0 if rs_ids is None else 1
-        rmsk_hits = annotations.get_rmsk_info(var)
-        in_cpg = annotations.get_cpg_island_info(var)
-        in_segdup = annotations.get_segdup_info(var)
-        is_conserved = annotations.get_conservation_info(var)
-        esp = annotations.get_esp_info(var)
-        thousandG = annotations.get_1000G_info(var)
-        recomb_rate = annotations.get_recomb_info(var)
-        gms = annotations.get_gms(var)
-        grc = annotations.get_grc(var)
-        in_cse = annotations.get_cse(var)
-        encode_tfbs = annotations.get_encode_tfbs(var)
-        encode_dnaseI = annotations.get_encode_dnase_clusters(var)
-        encode_cons_seg = annotations.get_encode_consensus_segs(var)
-        gerp_el = annotations.get_gerp_elements(var)
-        vista_enhancers = annotations.get_vista_enhancers(var)
-        cosmic_ids = annotations.get_cosmic_info(var)
-        fitcons = annotations.get_fitcons(var)
+        if var.end - var.POS < 50000:
+            pfam_domain = annotations.get_pfamA_domains(var)
+            cyto_band = annotations.get_cyto_info(var)
+            rs_ids = annotations.get_dbsnp_info(var)
+            clinvar_info = annotations.get_clinvar_info(var)
+            in_dbsnp = 0 if rs_ids is None else 1
+            rmsk_hits = annotations.get_rmsk_info(var)
+            in_cpg = annotations.get_cpg_island_info(var)
+            in_segdup = annotations.get_segdup_info(var)
+            is_conserved = annotations.get_conservation_info(var)
+            esp = annotations.get_esp_info(var)
+            thousandG = annotations.get_1000G_info(var)
+            recomb_rate = annotations.get_recomb_info(var)
+            gms = annotations.get_gms(var)
+            grc = annotations.get_grc(var)
+            in_cse = annotations.get_cse(var)
+            encode_tfbs = annotations.get_encode_tfbs(var)
+            encode_dnaseI = annotations.get_encode_dnase_clusters(var)
+            encode_cons_seg = annotations.get_encode_consensus_segs(var)
+            gerp_el = annotations.get_gerp_elements(var)
+            vista_enhancers = annotations.get_vista_enhancers(var)
+            cosmic_ids = annotations.get_cosmic_info(var)
+            fitcons = annotations.get_fitcons(var)
+            Exac = annotations.get_exac_info(var)
 
-        #load CADD scores by default
-        if self.args.skip_cadd is False:
-            (cadd_raw, cadd_scaled) = annotations.get_cadd_scores(var)
+            #load CADD scores by default
+            if self.args.skip_cadd is False:
+                (cadd_raw, cadd_scaled) = annotations.get_cadd_scores(var)
+            else:
+                (cadd_raw, cadd_scaled) = (None, None)
+
+            # load the GERP score for this variant by default.
+            gerp_bp = None
+            if self.args.skip_gerp_bp is False:
+                gerp_bp = annotations.get_gerp_bp(var)
+        # the variant is too big to annotate
         else:
-            (cadd_raw, cadd_scaled) = (None, None)
-
-        # load the GERP score for this variant by default.
-        gerp_bp = None
-        if self.args.skip_gerp_bp is False:
-            gerp_bp = annotations.get_gerp_bp(var)
+            pfam_domain = None
+            cyto_band = None
+            rs_ids = None
+            clinvar_info = annotations.ClinVarInfo()
+            in_dbsnp = None
+            rmsk_hits = None
+            in_cpg = None
+            in_segdup = None
+            is_conserved = None
+            esp = annotations.ESPInfo(None, None, None, None, None)
+            thousandG = annotations.ThousandGInfo(None, None, None, None, None, None, None)
+            Exac = annotations.ExacInfo(None, None, None, None, None, None, None, None, None, None)
+            recomb_rate = None
+            gms = annotations.GmsTechs(None, None, None)
+            grc = None
+            in_cse = None
+            encode_tfbs = None
+            encode_dnaseI = annotations.ENCODEDnaseIClusters(None, None)
+            encode_cons_seg = annotations.ENCODESegInfo(None, None, None, None, None, None)
+            gerp_el = None
+            vista_enhancers = None
+            cosmic_ids = None
+            fitcons = None                
+            cadd_raw = None
+            cadd_scaled = None
+            gerp_bp = None
 
         # impact is a list of impacts for this variant
         impacts = None
@@ -371,6 +403,7 @@ class GeminiLoader(object):
             gt_ref_depths = np.array(var.gt_ref_depths, np.int32)  # 2 21 0 -1
             gt_alt_depths = np.array(var.gt_alt_depths, np.int32)  # 8 16 0 -1
             gt_quals = np.array(var.gt_quals, np.float32)  # 10.78 22 99 -1
+            gt_copy_numbers = np.array(var.gt_copy_numbers, np.float32)  # 1.0 2.0 2.1 -1
 
             # tally the genotypes
             self._update_sample_gt_counts(gt_types)
@@ -382,6 +415,7 @@ class GeminiLoader(object):
             gt_ref_depths = None
             gt_alt_depths = None
             gt_quals = None
+            gt_copy_numbers = None
 
         if self.args.skip_info_string is False:
             info = var.INFO
@@ -404,6 +438,11 @@ class GeminiLoader(object):
                               impact.sift_pred, impact.sift_score]
                 variant_impacts.append(var_impact)
 
+        # extract structural variants
+        sv = svs.StructuralVariant(var)
+        ci_left = sv.get_ci_left()
+        ci_right = sv.get_ci_right()
+
         # construct the core variant record.
         # 1 row per variant to VARIANTS table
         if extra_fields:
@@ -415,9 +454,20 @@ class GeminiLoader(object):
                    var.var_subtype, pack_blob(gt_bases), pack_blob(gt_types),
                    pack_blob(gt_phases), pack_blob(gt_depths),
                    pack_blob(gt_ref_depths), pack_blob(gt_alt_depths),
-                   pack_blob(gt_quals),
+                   pack_blob(gt_quals), pack_blob(gt_copy_numbers),
                    call_rate, in_dbsnp,
                    rs_ids,
+                   ci_left[0],
+                   ci_left[1], 
+                   ci_right[0],
+                   ci_right[1],
+                   sv.get_length(), 
+                   sv.is_precise(),
+                   sv.get_sv_tool(),
+                   sv.get_evidence_type(),
+                   sv.get_event_id(),
+                   sv.get_mate_id(),
+                   sv.get_strand(),
                    clinvar_info.clinvar_in_omim,
                    clinvar_info.clinvar_sig,
                    clinvar_info.clinvar_disease_name,
@@ -429,6 +479,7 @@ class GeminiLoader(object):
                    clinvar_info.clinvar_disease_acc,
                    clinvar_info.clinvar_in_locus_spec_db,
                    clinvar_info.clinvar_on_diag_assay,
+                   clinvar_info.clinvar_causal_allele,
                    pfam_domain, cyto_band, rmsk_hits, in_cpg,
                    in_segdup, is_conserved, gerp_bp, gerp_el,
                    hom_ref, het, hom_alt, unknown,
@@ -449,10 +500,11 @@ class GeminiLoader(object):
                    infotag.get_allele_count(var), infotag.get_allele_bal(var),
                    infotag.in_hm2(var), infotag.in_hm3(var),
                    infotag.is_somatic(var),
+                   infotag.get_somatic_score(var),
                    esp.found, esp.aaf_EA,
                    esp.aaf_AA, esp.aaf_ALL,
                    esp.exome_chip, thousandG.found,
-                   thousandG.aaf_AMR, thousandG.aaf_ASN,
+                   thousandG.aaf_AMR, thousandG.aaf_EAS, thousandG.aaf_SAS,
                    thousandG.aaf_AFR, thousandG.aaf_EUR,
                    thousandG.aaf_ALL, grc,
                    gms.illumina, gms.solid,
@@ -471,7 +523,14 @@ class GeminiLoader(object):
                    pack_blob(info),
                    cadd_raw,
                    cadd_scaled,
-                   fitcons]
+                   fitcons,
+                   Exac.found,
+                   Exac.aaf_ALL,
+                   Exac.adj_aaf_ALL,
+                   Exac.aaf_AFR, Exac.aaf_AMR,
+                   Exac.aaf_EAS, Exac.aaf_FIN,
+                   Exac.aaf_NFE, Exac.aaf_OTH,
+                   Exac.aaf_SAS]
 
         return variant, variant_impacts, extra_fields
 
