@@ -136,6 +136,7 @@ def main():
         gemini_load.load(parser, args)
 
     parser_load.set_defaults(func=load_fn)
+
     #########################################
     # $ gemini amend
     #########################################
@@ -529,10 +530,12 @@ def main():
             help='The name of the database to be updated.')
     parser_get.add_argument('-w',
             dest='window_size',
+            type=int,
             default=1000000,
             help='The name of the column to be added to the variant table.')
     parser_get.add_argument('-s',
             dest='step_size',
+            type=int,
             default=0,
             help="The step size for the windows in bp.\n")
     parser_get.add_argument('-t',
@@ -893,49 +896,55 @@ def main():
     parser_set_somatic.add_argument('--min-depth',
             dest='min_depth',
             type=float,
-            default=30,
+            default=None,
             help='The min combined depth for tumor + normal (def: %(default)s).')
 
     parser_set_somatic.add_argument('--min-qual',
             dest='min_qual',
             type=float,
-            default=30,
+            default=None,
             help='The min variant quality (VCF QUAL) (def: %(default)s).')
 
+    parser_set_somatic.add_argument('--min-somatic-score',
+            dest='min_somatic_score',
+            type=float,
+            default=None,
+            help='The min somatic score (SSC) (def: %(default)s).')
+
     parser_set_somatic.add_argument('--max-norm-alt-freq',
             dest='max_norm_alt_freq',
             type=float,
-            default=0.03,
+            default=None,
             help='The max freq. of the alt. allele in the normal sample (def: %(default)s).')
 
     parser_set_somatic.add_argument('--max-norm-alt-count',
             dest='max_norm_alt_count',
             type=int,
-            default=2,
+            default=None,
             help='The max count. of the alt. allele in the normal sample (def: %(default)s).')
 
     parser_set_somatic.add_argument('--min-norm-depth',
             dest='min_norm_depth',
             type=int,
-            default=10,
+            default=None,
             help='The minimum depth allowed in the normal sample to believe somatic (def: %(default)s).')
 
     parser_set_somatic.add_argument('--min-tumor-alt-freq',
             dest='min_tumor_alt_freq',
             type=float,
-            default=0.05,
+            default=None,
             help='The min freq. of the alt. allele in the tumor sample (def: %(default)s).')
 
     parser_set_somatic.add_argument('--min-tumor-alt-count',
             dest='min_tumor_alt_count',
             type=int,
-            default=2,
+            default=None,
             help='The min count. of the alt. allele in the tumor sample (def: %(default)s).')
 
     parser_set_somatic.add_argument('--min-tumor-depth',
             dest='min_tumor_depth',
             type=int,
-            default=10,
+            default=None,
             help='The minimum depth allowed in the tumor sample to believe somatic (def: %(default)s).')
 
     parser_set_somatic.add_argument('--chrom',
@@ -979,6 +988,9 @@ def main():
                                action="store_true", default=False)
     parser_update.add_argument("--extra", help="Add additional non-standard genome annotations to include",
                                action="append", default=[], choices=["gerp_bp","cadd_score"])
+    parser_update.add_argument("--tooldir", help="Directory for third party tools (ie /usr/local) update")
+    parser_update.add_argument("--sudo", help="Use sudo for tool installation commands",
+                               dest="sudo", action="store_true", default=False)
     def update_fn(parser, args):
         import gemini_update
         gemini_update.release(parser, args)
@@ -1039,6 +1051,43 @@ def main():
         from tool_homozygosity_runs import run
         run(parser, args)
     parser_hom_run.set_defaults(func=homozygosity_runs_fn)
+    
+
+    #########################################
+    # $ gemini fusions
+    #########################################
+    parser_fusions = subparsers.add_parser('fusions',
+                                         help="Identify somatic fusion genes from a GEMINI database.")
+    parser_fusions.add_argument('db',
+                              metavar='db',
+                              help='The name of the database to be queried.')
+    parser_fusions.add_argument('--sample',
+                              metavar='sample',
+                              default=None,
+                              help='New sample information file to load')
+    parser_fusions.add_argument('--in_cosmic_census',
+                                action='store_true',
+                                help='One or both genes in fusion is in COSMIC cancer census')
+    parser_fusions.add_argument('--min_qual',
+                                dest='min_qual',
+                                metavar='FLOAT',
+                                type=float,
+                                default=None,
+                                help='The min variant quality (VCF QUAL) (def: %(default)s).')
+    parser_fusions.add_argument('--evidence_type',
+                                metavar='STR',
+                                dest='evidence_type',
+                                type=str,
+                                default=None,
+                                help='The supporting evidence types for the variant ("PE", "SR", or "PE,SR").')
+
+    def fusions_fn(parser, args):
+        from tool_fusions import run
+        run(parser, args)
+    parser_fusions.set_defaults(func=fusions_fn)
+
+
+
     #######################################################
     # parse the args and call the selected function
     #######################################################
