@@ -18,7 +18,7 @@ The recommended Gemini install location is /usr/local/share/gemini.
 """
 
 anno_files = \
-['dbsnp.hg19.b141.vcf.gz',
+['dbsnp.b141.20140813.hg19.vcf.gz',
 'clinvar_20140807.vcf.gz',
 '29way_pi_lods_elements_12mers.chr_specific.fdr_0.1_with_scores.txt.hg19.merged.bed.gz',
 'hg19.CpG.bed.gz',
@@ -30,7 +30,7 @@ anno_files = \
 'hg19.rmsk.bed.gz',
 'hg19.segdup.bed.gz',
 'ESP6500SI.all.snps_indels.vcf.gz',
-'ALL.wgs.integrated_phase1_v3.20101123.snps_indels_sv.sites.2012Oct12.vcf.gz',
+'ALL.autosomes.phase3_shapeit2_mvncall_integrated_v5.20130502.sites.vcf.gz',
 'genetic_map_HapMapII_GRCh37.gz',
 'wgEncodeRegTfbsClusteredV2.cell_count.20130213.bed.gz',
 'encode.6celltypes.consensus.bedg.gz',
@@ -50,16 +50,17 @@ anno_files = \
 'detailed_gene_table_v75',
 'summary_gene_table_v75',
 'cancer_gene_census.20140120.tsv',
-'hg19_fitcons_fc-i6-0_V1-01.bw'
+'hg19_fitcons_fc-i6-0_V1-01.bw',
+'ExAC.r0.2.sites.vep.vcf.gz'
 ]
 extra_anno_files = {"gerp_bp": "hg19.gerp.bw", "cadd_score": "whole_genome_SNVs.tsv.compressed.gz"}
 
-custom_downloads = {"hg19_fitcons_fc-i6-0_V1-01.bw":
-                    "http://compgen.bscb.cornell.edu/fitCons/0downloads/tracks/V1.01/i6/scores/fc-i6-0.bw"}
+custom_downloads = {}
 
 toadd_anno_files = []
 
 anno_versions = {
+    "ALL.autosomes.phase3_shapeit2_mvncall_integrated_v5.20130502.sites.vcf.gz": 2,
     "GRCh37-gms-mappability.vcf.gz": 2,
     "dbsnp.hg19.b141.vcf.gz": 3,
     "clinvar_20140807.vcf.gz": 4,
