@@ -410,14 +410,14 @@ rm obs exp
 # 22. Test transposed ped (TPED) query format
 ########################################################################
 echo "    query.t22...\c"
-echo "10 10:1142207-1142208:C:1 0 1142207 C C C C C C C C
+echo "10 10:1142207-1142208:T|C:1 0 1142207 C C C C C C C C
 10 10:48003991-48003992:C|T:2 0 48003991 T T C T C T C C
-10 10:52004314-52004315:C:3 0 52004314 0 0 0 0 C C C C
-10 10:52497528-52497529:C:4 0 52497528 0 0 C C C C 0 0
-10 10:126678091-126678092:A|G:5 0 126678091 G G G G G G G A
-10 10:135210790-135210791:C|T:6 0 135210790 T T C C C C T T
-10 10:135336655-135336656:A:7 0 135336655 0 0 A A 0 0 A A
-10 10:135369531-135369532:C|T:8 0 135369531 T T T C T C T T
+10 10:52004314-52004315:T|C:3 0 52004314 0 0 0 0 C C C C
+10 10:52497528-52497529:G|C:4 0 52497528 0 0 C C C C 0 0
+10 10:126678091-126678092:G|A:5 0 126678091 G G G G G G G A
+10 10:135210790-135210791:T|C:6 0 135210790 T T C C C C T T
+10 10:135336655-135336656:G|A:7 0 135336655 0 0 A A 0 0 A A
+10 10:135369531-135369532:T|C:8 0 135369531 T T T C T C T T
 16 16:72057434-72057435:C|T:9 0 72057434 C T C C C C C C" > exp
 gemini query --format tped -q "select * from variants" test4.snpeff.ped.db > obs
 check obs exp
