@@ -268,10 +268,42 @@ chr10	1142207	1142208	T	C	WDR37	C/C	C/C	C/C	C/C
 chr10	48003991	48003992	C	T	ASAH2C	T/T	C/T	C/T	C/C
 chr10	52004314	52004315	T	C	ASAH2	./.	./.	C/C	C/C
 chr10	52497528	52497529	G	C	ASAH2B	./.	C/C	C/C	./.
-chr10	135210790	135210791	T	C	MTG1.1	T/T	C/C	C/C	T/T
-chr10	135336655	135336656	G	A	SPRN	./.	A/A	./.	A/A
-chr10	135369531	135369532	T	C	SYCE1	T/T	T/C	T/C	T/T" > exp
+chr10	135336655	135336656	G	A	SPRN	./.	A/A	./.	A/A" > exp
 gemini query --header -q "select chrom, start, end, ref, alt, gene, (gts).(*) from variants" \
              --gt-filter "((gt_types).(phenotype==1).(!=HOM_REF).(count>=1) and (gt_types).(phenotype==2).(!=HOM_REF).(count>=1))" extended_ped.db > obs
 check obs exp
 rm obs exp
+
+########################################################################
+# 20. Test multiple wildcard on same column
+########################################################################
+echo "    wildcard.t20...\c"
+echo "chrom	start	end	ref	alt	gene	gts.M10475	gts.M10478	gts.M10500	gts.M128215" > exp
+gemini query --header -q "select chrom, start, end, ref, alt, gene, (gts).(*) from variants" \
+             --gt-filter "((gt_types).(phenotype==1).(!=HOM_REF).(all) and (gt_types).(phenotype==2).(==HOM_REF).(all))" extended_ped.db > obs
+check obs exp
+rm obs exp
+
+########################################################################
+# 21. Test multiple wildcard on same column
+########################################################################
+echo "    wildcard.t21...\c"
+echo "chrom	start	end	ref	alt	gene	gts.M10475	gts.M10478	gts.M10500	gts.M128215
+chr10	126678091	126678092	G	A	CTBP2	G/G	G/G	G/G	G/A
+chr16	72057434	72057435	C	T	DHODH	C/T	C/C	C/C	C/C" > exp
+gemini query --header -q "select chrom, start, end, ref, alt, gene, (gts).(*) from variants" \
+             --gt-filter "((gt_types).(phenotype==1).(!=HOM_REF).(count>=1) and (gt_types).(phenotype==2).(==HOM_REF).(all))" extended_ped.db > obs
+check obs exp
+rm obs exp
+
+########################################################################
+# 22. Test AND 
+########################################################################
+echo "    wildcard.t22...\c"
+echo "chrom	start	end	ref	alt	gene	gts.M10475	gts.M10478	gts.M10500	gts.M128215
+chr10	126678091	126678092	G	A	CTBP2	G/G	G/G	G/G	G/A
+chr16	72057434	72057435	C	T	DHODH	C/T	C/C	C/C	C/C" > exp
+gemini query --header -q "select chrom, start, end, ref, alt, gene, (gts).(*) from variants" \
+             --gt-filter "((gt_types).(phenotype==1).(!=HOM_REF).(count>=1) AND (gt_types).(phenotype==2).(==HOM_REF).(all))" extended_ped.db > obs
+check obs exp
+rm obs exp
